@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "globalparttest.h"
-#include <QTest>
 #include <../src/part/globalpart.h>
+#include <QTest>
 GlobalPartTest::GlobalPartTest(QObject *parent)
     : QObject(parent)
 {
@@ -27,4 +27,4 @@ void GlobalPartTest::shouldHaveDefaultValue()
     QVERIFY(!globalpart.requestDeleveryConfirmation());
 }
 
-QTEST_MAIN(GlobalPartTest)
+QTEST_GUILESS_MAIN(GlobalPartTest)
