@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,16 +7,16 @@
 #include "testdndwebengine.h"
 
 #include <QApplication>
+#include <QDebug>
+#include <QTextEdit>
 #include <QVBoxLayout>
 #include <webengineview.h>
-#include <QTextEdit>
-#include <QDebug>
 
 TestDndWebEngine::TestDndWebEngine(QWidget *parent)
     : QWidget(parent)
 {
-    auto *vbox = new QVBoxLayout(this);
-    auto *layout = new QHBoxLayout;
+    auto vbox = new QVBoxLayout(this);
+    auto layout = new QHBoxLayout;
     vbox->addLayout(layout);
     pageView = new WebEngineViewer::WebEngineView(this);
     pageView->load(QUrl(QStringLiteral("http://www.planetkde.org")));
@@ -26,7 +26,7 @@ TestDndWebEngine::TestDndWebEngine(QWidget *parent)
     webEngineView->load(QUrl(QStringLiteral("http://www.kde.org")));
     layout->addWidget(webEngineView);
 
-    auto *edit = new QTextEdit(this);
+    auto edit = new QTextEdit(this);
     vbox->addWidget(edit);
 }
 
@@ -38,7 +38,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    auto *testWebEngine = new TestDndWebEngine;
+    auto testWebEngine = new TestDndWebEngine;
     testWebEngine->show();
     const int ret = app.exec();
     return ret;
